Config

Struct Config 

#[repr(C)]
pub struct Config { pub base_reward_rate: u64, pub last_reset_at: i64, pub min_difficulty: u64, pub top_balance: u64, pub evolver: Pubkey, pub evolvable: u64, }
Config is a singleton account which manages program global variables.

Fields

base_reward_rate: u64

The base reward rate paid out for a hash of minimum difficulty.

last_reset_at: i64

The timestamp of the last reset.

min_difficulty: u64

The minimum accepted difficulty.

top_balance: u64

The largest known stake balance on the network from the last epoch.

evolver: Pubkey

The mars evolution authority with permission to update/change the evolver. The evolver decides the evolution fate of Mars

evolvable: u64

Is mars evolvable, i.e. from mars to marsh.

Implementations

Source

impl Config

pub fn to_bytes(&self) -> &[u8]